@@ -1,4 +1,8 @@
+"""Snide: a remark.js parser in python"""
+
 __author__ = 'Michael Joseph'
 __email__ = 'michaeljoseph@gmail.com'
 __url__ = 'https://github.com/michaeljoseph/snide'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
+
+from .models import Deck, Slide
\ No newline at end of file
